% Script file: PLDATA.m
%
% Purpose:
%    This M-file prapares the data for the program PLBECON to analyze
%    the plate of Example 2.2
%
%  Record of revisions:
%      Date       Programmer         Description of change
%      ====       ==========         =====================
%   15/10/2012    J.T.Katsikadelis    Original code
%
clear all;
global xl yl xb yb xin yin xsl ysl xps yps xll yll xcl ycl nst nps nlt ncl 
fprintf('********* PLDATA ********** \n');
inputfile=input('Enter file name for plate:','s');
fid = fopen (inputfile,'w');
user=input('User name:','s');
title=input('Title:','s');
%==========================================================================
% ELASTIC CONSTANTS
%==========================================================================
el=2100000;  % Modulus of elasticity
pn=0.2;      % Poisson ratio
%==========================================================================
% PLATE THICKNESS
%==========================================================================
hplate=0.2;
%==========================================================================
% BOUNDARY DATA
%==========================================================================
nb=2;                       % number of boundaries
%
ns=5;                       % number of sides.
% A side is defined as a part of the boundary between the corner points.
% Points where the boundary conditions change and boundary support points 
% are treated as corner points.
% Parts of the boundary with different geometry are different sides.

% Give the side properties.
%ATENSION: External boundaries are run  anticlockwise,
%          internal boundaries clockwise.
%------------------------ms-------------------------------
%        1      2       3    4      5     6       7
%---------------------------------------------------------
%line  : 1 | No of BE | x1 | y1  | x2   | y2   | unused  |
%          |          |    |     |      |      |         |
%          |          |    |     |      |      |         |
%circle: 2 | No of BE | x0 | y0  | phi1 | phi2 | radious |
%          |          |    |     |      |      |         |
%          |          |    |     |      |      |         |
%---------------------------------------------------------
% Give: 1 for straight line; 2 for circular arc
% x1               : x coordinate  of the starting point
% y1               : y coordinate  of the starting point
% x2               : x coordinate  of the end point
% y2               : y coordinate  of the end point

% x0               : x coordinate  of the center of the circular arc
% y0               : y coordinate  of the center of the circular arc
% phi1, phi2       : limit angles of the circular arc

% ms:= array including the side properties
ms=zeros(ns,7);
ms=[ 1  ,  150,   0   ,   0    ,   10.5  , 0 ,   0 ;
     2  ,  300,  10.5   ,  5    ,   -pi/2  , pi/2 , 5 ;
     1  ,  150,  10.5   ,   10    ,   0  , 10 ,   0 ;
     1  ,  100,  0   ,   10    ,   0  , 0 ,   0 ;
     2  ,  200,  6.5   ,   5    ,   0  , -2*pi ,   1.5 ];
%  CALL function: boundarypoints.m
%                 For the meanning of the output parameters see function
%                 boundarypoints.m
nl=zeros(nb,1);
nl=[700; 900];             % serial number of the last element of each boundary
[nbe,xb,yb,xl,yl,jn,kn,cn,sn,cur,length]=boundarypoints(ms,ns,nl);

% Corner point properties
nc=4;             % number of corner points

%----------------mc----------------
%  1      2      3      4   |  5  |
%----------------------------------
% code |  xc  |  yc  | value| kT  |
%      |      |      |      |     |
%      |      |      |      |     |
%----------------------------------

%  xc       : x coordinate  of the corner point
%  yc       : y coordinate  of the corner point
%  code=0   : corner with at least one adjacent supported edge
%                         value= unused in this case
%  code=1   : supported corner between free  edges
%                         value=prescribed displacement w
%  code=2   : free corner between free  edges
%                         value=prescribed corner force R
%  kT       : transverse elastic support at corner point
%             between free edges. kT= prescribed spring stiffness

% mc:= array including the corner properties
if nc > 0
    mc=zeros(nc,5);
    mc=[ 0,   0  ,   0,    0, 0;
        2,   10.5  ,   0,    0, 0;
        2,   10.50  ,   10,    0, 0;
        0,   0  ,   10,    0, 0];
end
%==========================================================================
% ASSIGN boundary conditions at the nbe boundary nodal points
%==========================================================================

% Boundary conditions for each side:
% ********************************************************************
% *                   |  a1   |  a2  |  a3  |  b1   |  b2   |  b3  | *
% ********************************************************************
% * Simply supported  |  1    |  0   |  w*  |   0   |   1   |  Mn* | *
% * Clamped           |  1    |  0   |  w*  |   1   |   0   |  wn* | *
% * Free              |  0    |  1   |  Vn* |   0   |   1   |  Mn* | *
% * Guided            |  0    |  1   |  Vn* |   0   |   1   |  wn* | *
% * Elastic support   |  kT   |  1   |  Vn* |   kR  |   1   |  Mn* | *
% ********************************************************************
%
%    kT and kR are the transverse and rotational spring stiffnesses
%    The star designates prescribed quantity

% abs:= array including the values of a1,a2,a3,b1,b2,b3 of each side
%----------------abs-------------------|
%        | 1  |  2 | 3  |  4 |  5 |  6 |
%--------------------------------------
% side 1 | a1 | a2 | a3 | b1 | b2 | b3 | 
% side 2 | ...                         |
% ...  
% side ns| ...                         | 
%--------------------------------------|

abs=zeros(ns,6);
abs=[
0,1,0,0,1,0;
0,1,0,0,1,0;
0,1,0,0,1,0;
1,0,0,0,1,0;
0,1,0,0,1,0];

% ab:= array where the boundary conditions coefficients a1,a2,a3 and
% b1,b2,b3 of each boundary element are stored
ab=zeros(nbe,6);
ik=0;
for i=1:ns
    for j=1:ms(i,2)
        ik=ik+1;
        ab(ik,:)=abs(i,:);
    end
end
%==========================================================================
% GENERATION of the coorinates of the IN interior nodal points xin,yin
% where deflections and the stress resultants will be evaluated.
%==========================================================================
% First a rectangular mesh with nrow X ncol nodal points is applied on the
% domain of the  plate.Then the function checkin.m detects the nodal points
% inside the domain. Points at a distance from the boundary smaller than a
% prescribed value "dist" are excluded.
% -------------------------------------------------------------------------
% CALL function meshpoints to generate nrow X ncol nodal points
nrow=15;
ncol=29;
[xint,yint,mt]=meshpoints(nrow,ncol,xl,yl); 
%==========================================================================
% CALL function checkin.m to detect points inside the domain of the plate
%==========================================================================
dist=0.2;  %the minimum distance of the internal points from the boundary
[m,xin,yin]=checkin(nbe,mt,xb,yb,xint,yint,cn,sn,length,dist);
fprintf(' Total number of interior nodal points \n');
m
% m  = final total number of the interior nodal points
%==========================================================================
% LINE SUPPORTS
%==========================================================================
nst=1;               % nst=number of line supports
if nst > 0
    msl=[30];        % number of elements on each line support
    xa=[10.5];        % x coordinates of the origin of each line support
    ya=[3.5];          % y coordinates of the origin of each line support
    xt=[10.5];        % x coordinates of the end of each line support
    yt=[6.5];        % x coordinates of the end of each line support

    [xsl,ysl,nsl]=linesl(nst,msl,xa,ya,xt,yt);
end
%==========================================================================
% POINT SUPPORTS
%==========================================================================
nps=0;               %  nps=number of point supports
if nps > 0
    xps=[12.5; 12.5];       %  x coordinates of point supports
    yps=[3.5; 6.5];       %  y coordinates of point supports
end
%==========================================================================
% SURFACE LOADS
%==========================================================================
% fx,fy,f0 : coefficients of the linear load function f=fx*x+fy*y+f0
fx=0;
fy=0;
f0=1;
%==========================================================================
% LINE LOADS
%==========================================================================
nlt=0;               % number of line loads
if nlt > 0
    mll=[10,10];     % number of elements on each line load
    xa=[1,2];        % x coordinates of the origin of each line load
    ya=[0.5,0.2];    % y coordinates of the origin of each line load
    xt=[4,2];        % x coordinates of the end of each line load
    yt=[0.5,1];      % y coordinates of the end of each line load
    [xll,yll,nll]=linesl(nlt,mll,xa,ya,xt,yt);
    
    for ii=1:nll
        fll(ii)=1;  % value of the line load at the center of each element 
    end
        
end
%==========================================================================
% POINT LOADS
%==========================================================================
ncl=0;              % number of point loads
if ncl > 0
    xcl=[2.1;2];    % x coordinates of point loads
    ycl=[1;1.5];    % x coordinates of point loads
    fcl=[1;1];      % values of point loads
end
%==========================================================================
% PLOT GEOMETRY and NODAL POINTS
%==========================================================================
% CALL function plotplate to view geometry and nodal points
plotplate;
%==========================================================================
% WRITE DATA in the inputfile
%==========================================================================
fprintf(fid,user );
fprintf(fid,'\n');
fprintf(fid,title );
fprintf(fid,'\n');
fprintf(fid,'%6.0f %6.3f %6.3f\n',el,pn,hplate);
for ii=1:nb
    fprintf(fid,'%6.0f \n',nl(ii));
end
for ii=1:nbe
    fprintf(fid,'%6.8f %14.8f \n',xl(ii),yl(ii));
end
for ii=1:nc
    fprintf(fid,'%6.0f %6.8f %6.8f %6.8f %6.8f\n',mc(ii,1),mc(ii,2) ...
        ,mc(ii,3),mc(ii,4),mc(ii,5));
end

for ii=1:nbe
    fprintf(fid,'%5.5f %5.5f %5.5f %5.5f %5.5f %5.5f %5.5f\n', ...
        ab(ii,1),ab(ii,2),ab(ii,3),ab(ii,4),ab(ii,5),ab(ii,6),cur(ii));
end

if nst > 0
    finp=0;
    for ii=1:nst
        finp=finp+msl(ii);
        fprintf(fid,'%6.0f \n',finp);
    end

    for ii=1:nsl
        fprintf(fid,'%6.2f %6.2f\n',xsl(ii),ysl(ii));
    end
end

for ii=1:nps
    fprintf(fid,'%6.2f %6.2f\n',xps(ii),yps(ii));
end

fprintf(fid,'%6.2f %6.2f %6.2f\n',fx,fy,f0);
if nlt > 0
    finp=0;
    for ii=1:nlt
        finp=finp+mll(ii);
        fprintf(fid,'%6.0f \n',finp);
    end

    for ii=1:nll
        fprintf(fid,'%6.2f %6.2f %6.2f\n',xll(ii),yll(ii),fll(ii));
    end
end

for ii=1:ncl
    fprintf(fid,'%6.2f %6.2f %6.2f\n',xcl(ii),ycl(ii),fcl(ii));
end

for ii=1:m
    fprintf(fid,'%6.4f %10.4f \n',xin(ii),yin(ii));
end

fclose(fid);

